/*!
	@header NSImage_Base64Encoding.h
	@discussion	This contains an extension to the NSImage class that handles Base 64 encoding of image data.
				This functionality may be useful for web work or, more generally, for embedding bitmap data in
				XML documents.

				Requires the NSData_Base64Encoding category to do the actual encoding/decoding.

	Created by khammond on Mon Oct 29 2001.
	@updated	07-07-2010
	@copyright	2001, 2005, 2010 Kyle Hammond
 
@textblock
 Copyright (c) 2001, 2005, 2010, Kyle Hammond
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 
 - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 
 - Neither the name of the Snowmint Creative Solutions LLC nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 @/textblock
 */
#import <Cocoa/Cocoa.h>

@interface NSImage (Base64Encoding)

extern NSString *kXML_Base64ReferenceAttribute;

/*!	@function	+dataWithBase64EncodedString:
	@discussion	This method returns an autoreleased NSImage object.  The NSImage object is initialized with the
				contents of the Base 64 encoded string.  This is a convenience function for
				-initWithBase64EncodedString:.
	@param	inBase64String	An NSString object that contains only Base 64 encoded data representation of an image.
	@result	The NSImage object.
*/
+ (NSImage *)imageWithBase64EncodedString:(NSString *)inBase64String;

/*!	@function	-initWithBase64EncodedString:
	@discussion	The NSImage object is initialized with the contents of the Base 64 encoded string.
				This method returns self as a convenience.
	@param	inBase64String	An NSString object that contains only Base 64 encoded image data.
	@result	This method returns self.
*/
- (id)initWithBase64EncodedString:(NSString *)inBase64String;

/*!	@function	-base64EncodingWithFileType:
	@discussion	This method returns a Base 64 encoded string representation of the NSImage object.
	@param	inFileType	The image is first converted to this file type, then encoded in Base 64.
	@result	The base 64 encoded image data string.
*/
- (NSString *)base64EncodingWithFileType:(NSBitmapImageFileType)inFileType;

@end
