//
//  NSImage_Base64Encoding.m
//
//  Created by khammond on Mon Oct 29 2001.
//Copyright (c) 2001, 2005, 2010, Kyle Hammond
//All rights reserved.
//
//Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//
//- Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//
//- Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//
//- Neither the name of the Snowmint Creative Solutions LLC nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
#import "NSImage_Base64Encoding.h"
#import "NSData_Base64Encoding.h"

@implementation NSImage (Base64Encoding)

NSString *kXML_Base64ReferenceAttribute = @"xlink:href=\"data:;base64,";

+ (NSImage *)imageWithBase64EncodedString:(NSString *)inBase64String
{
	NSImage	*result = nil;

	result = [ [ NSImage alloc ] initWithBase64EncodedString:inBase64String ];

	return [ result autorelease ];
}

- (id)initWithBase64EncodedString:(NSString *)inBase64String
{
	if ( inBase64String )
	{
		NSSize		tempSize = { 100, 100 };
		NSData		*data = nil;
		NSImageRep	*imageRep = nil;

		self = [ self initWithSize:tempSize ];

		if ( self )
		{
			// Now, interpret the inBase64String.
			data = [ NSData dataWithBase64EncodedString:inBase64String ];

			if ( data )
				// Create an image representation from the data.
				imageRep = [ NSBitmapImageRep imageRepWithData:data ];

			if ( imageRep )
			{
				// Set the real size of the image and add the representation.
				[ self setSize:[ imageRep size ] ];

				[ self addRepresentation:imageRep ];
			}
		}

		return self;
	} else
		return nil;
}

- (NSString *)base64EncodingWithFileType:(NSBitmapImageFileType)inFileType
{
	NSString			*result = nil;
	NSBitmapImageRep	*imageRep = nil;
	NSData				*t_filetype_data = nil;
	NSEnumerator		*enumerator;
	id					object;
	NSMutableDictionary	*dict;

	// Look for an existing representation in the NSBitmapImageRep class.
	enumerator = [ [ self representations ] objectEnumerator ];
	while ( imageRep == nil && ( object = [ enumerator nextObject ] ) != nil )
	{
		if ( [ object isKindOfClass:[ NSBitmapImageRep class ] ] )
			imageRep = object;
	}

	if ( imageRep == nil )
	{
		// Need to make a NSBitmapImageRep for so we can get whatever the caller wants later.
		imageRep = [ NSBitmapImageRep imageRepWithData:[ self TIFFRepresentation ] ];
		if ( imageRep )
			[ self addRepresentation:imageRep ];
	}

	if ( imageRep != nil )
	{	// Get the image data as whatever type the caller wants.
		dict = [ NSMutableDictionary dictionaryWithCapacity:1 ];
		[ dict setObject:[ NSNumber numberWithBool:NO ] forKey:NSImageInterlaced ];
		t_filetype_data = [ imageRep representationUsingType:inFileType properties:dict ];
	}

	if ( t_filetype_data != nil )
		// Now, convert the t_filetype_data into Base64 encoding.
		result = [ t_filetype_data base64EncodingWithLineLength:78 ];

	return result;
}

@end
